##
##  php-apcu.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         php-apcu
Summary:      Alternative PHP Cache
URL:          http://pecl.php.net/package/APCu
Vendor:       Joe Watkins et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Language
License:      PHP
Version:      5.1.23
Release:      20231115

#   package options
%option       with_apache  yes

#   list of sources
Source0:      https://pecl.php.net/get/apcu-%{version}.tgz
Source1:      php-apcu.ini

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, libtool, autoconf, automake
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  php
PreReq:       php
%if "%{with_apache}" == "yes"
PreReq:       apache, apache-php
%endif

%description
    Alternative PHP Cache (APC) is an opcode cache for PHP/Zend.

%track
    prog php-apcu = {
        version   = %{version}
        url       = http://pecl.php.net/package/APCu
        regex     = apcu-(\d+(\.\d+)+)\.tgz
    }

%prep
    %setup -q -n apcu-%{version}

%build
    #   configure module
    %{l_prefix}/bin/phpize
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-php-config=%{l_prefix}/bin/php-config \
        --enable-apcu \
        --enable-shared \
        --disable-static

    #   build module
    %{l_make} %{l_mflags -O}

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/php-apcu \
        $RPM_BUILD_ROOT%{l_prefix}/lib/php-apcu \
        $RPM_BUILD_ROOT%{l_prefix}/share/php-apcu

    #   install module
    %{l_shtool} install -c -m 755 \
        .libs/apcu.so $RPM_BUILD_ROOT%{l_prefix}/libexec/php-apcu/

    #   install PHP configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE php-apcu.ini} $RPM_BUILD_ROOT%{l_prefix}/share/php-apcu/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

%post
    if [ ".$1" = .1 ]; then
        #   add hook to PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/php/php.ini"
        if [ -f $phpini ]; then
            cat $RPM_INSTALL_PREFIX/share/php-apcu/php-apcu.ini |\
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -a -i "$RPM_INSTALL_PREFIX:php-apcu" -p ";" $phpini
        fi
%if "%{with_apache}" == "yes"
        #   add hook to Apache/PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/apache/apache-php.ini"
        if [ -f $phpini ]; then
            cat $RPM_INSTALL_PREFIX/share/php-apcu/php-apcu.ini |\
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -a -i "$RPM_INSTALL_PREFIX:php-apcu" -p ";" $phpini
        fi
%endif
    fi

%postun
    if [ ".$1" = .0 ]; then
        #   remove hook from PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/php/php.ini"
        if [ -f $phpini ]; then
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -r -i "$RPM_INSTALL_PREFIX:php-apcu" -p ";" $phpini
        fi
%if "%{with_apache}" == "yes"
        #   remove hook from Apache/PHP configuration
        phpini="$RPM_INSTALL_PREFIX/etc/apache/apache-php.ini"
        if [ -f $phpini ]; then
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -r -i "$RPM_INSTALL_PREFIX:php-apcu" -p ";" $phpini
        fi
%endif
    fi

